﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using StockSharp.TraderConnection;
using StockSharp.BusinessEntities;
using StockSharp.Quik;
using Ecng.Common;
using Ecng.Xaml;

namespace DonchianChannel
{
    public partial class MainWindow : Window
    {
        private const string securityCode = "SiZ3";

        private SafeConnection _connection;

        private Security _security = new Security();
        private Portfolio _portfolio = new Portfolio();

        private TimeSpan _timeFrame = TimeSpan.FromMinutes(60);




        public MainWindow()
        {
            InitializeComponent();
            _connection = new SafeConnection(new QuikTrader(QuikTerminal.GetDefaultPath()));
        }

        protected override void OnClosing(System.ComponentModel.CancelEventArgs e)
        {
            if (_connection != null)
                _connection.DisConnectSafe();
            base.OnClosing(e);
        }

        private void btnConnect_Click(object sender, RoutedEventArgs e)
        {
            if (_connection == null)
                return;

            if (!_connection.IsConnected)
            {
                btnConnect.IsEnabled = false;

                Action<IEnumerable<Security>> newSecurities = null;
                newSecurities = securities => this.GuiAsync(() =>
                    {
                        foreach (Security sec in securities)
                        {
                            if (sec.Code == securityCode)
                            {
                                _connection.Trader.NewSecurities -= newSecurities;
                                tbSecurity.Background = new SolidColorBrush(Colors.AntiqueWhite);
                                tbSecurity.Text = sec.Name;
                                _security = sec;
                            }
                        }
                    });

                Action<IEnumerable<Portfolio>> newPortfolios = null;
                newPortfolios = portfolios => this.GuiAsync(() => 
                    {
                        foreach (Portfolio port in portfolios)
                        {
                            if (port.Name == "SPBFUT00EY2")
                            {
                                _connection.Trader.NewPortfolios -= newPortfolios;
                                tbPortfolio.Background = new SolidColorBrush(Colors.AntiqueWhite);
                                tbPortfolio.Text = port.Name;
                                _portfolio = port;
                            }
                        }
                    });

                Action connected = null;
                connected = () =>
                    {
                        _connection.Trader.Connected -= connected;
                        this.GuiAsync(() =>
                            {
                                btnConnect.Background = new SolidColorBrush(Colors.LightCoral);
                                btnConnect.Content = "Disconnect";
                                btnConnect.IsEnabled = true;
                            });
                    };
                
                _connection.Trader.NewSecurities += newSecurities;
                _connection.Trader.NewPortfolios += newPortfolios;
                _connection.Trader.Connected += connected;

                _connection.ConnectSafe();
            }

            else
            {
                btnConnect.IsEnabled = false;

                Action disconnected = null;
                disconnected = () =>
                    {
                        _connection.Trader.Disconnected -= disconnected;
                        this.GuiAsync(() =>
                        {
                            tbSecurity.Clear();
                            tbPortfolio.Clear();
                            tbSecurity.Background = new SolidColorBrush(Colors.White);
                            tbPortfolio.Background = new SolidColorBrush(Colors.White);
                            btnConnect.Background = new SolidColorBrush(Colors.LightGreen);
                            btnConnect.Content = "Connect";
                            btnConnect.IsEnabled = true;
                        });
                    };

                _connection.Trader.Disconnected += disconnected;

                _connection.DisConnectSafe();
            }
        }


    }
}
